﻿using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart;
using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 축 1
        /// </summary>
        private Axis axis1;

        /// <summary>
        /// 축 2
        /// </summary>
        private Axis axis2;

        /// <summary>
        /// 축 3
        /// </summary>
        private Axis axis3;

        /// <summary>
        /// 캔들 시리즈
        /// </summary>
        private Candle candle;

        /// <summary>
        /// 볼륨 시리즈
        /// </summary>
        private Volume volume;

        /// <summary>
        /// OBV 함수
        /// </summary>
        private OBVFunction obvFunction;

        /// <summary>
        /// 라인 시리즈
        /// </summary>
        private Line line;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 축 1을 생성한다.

            this.axis1 = new Axis();

            this.axis1.StartPosition = 0d;
            this.axis1.EndPosition   = 37d;
            this.axis1.MaximumOffset = 5;
            this.axis1.MinimumOffset = 5;

            #endregion
            #region 축 2를 생성한다.

            this.axis2 = new Axis();

            this.axis2.StartPosition = 40d;
            this.axis2.EndPosition   = 66d;

            #endregion
            #region 축 3을 생성한다.

            this.axis3 = new Axis();

            this.axis3.StartPosition = 68d;
            this.axis3.EndPosition   = 100d;

            #endregion

            #region 캔들 시리즈를 생성한다.

            this.candle = new Candle();

            this.candle.Title          = "Candle";
            this.candle.Brush.Color    = Color.Red;
            this.candle.Color          = Color.FromArgb(68, 102, 163);
            this.candle.VertAxis       = VerticalAxis.Custom;
            this.candle.CustomVertAxis = this.axis1;

            #endregion
            #region 볼륨 시리즈를 생성한다.

            this.volume = new Volume();

            this.volume.Title          = "Volume";
            this.volume.Brush.Color    = Color.FromArgb(243, 156, 53);
            this.volume.Color          = Color.FromArgb(243, 156, 53);
            this.volume.VertAxis       = VerticalAxis.Custom;
            this.volume.CustomVertAxis = this.axis2;

            #endregion
            #region OBV 함수를 생성한다.

            this.obvFunction = new OBVFunction();

            this.obvFunction.Period = 1d;
            this.obvFunction.Volume = this.volume;

            #endregion
            #region 라인 시리즈를 생성한다.

            this.line = new Line();

            this.line.Title          = "OBV Function";
            this.line.Brush.Color    = Color.Red;
            this.line.Color          = Color.Red;
            this.line.VertAxis       = VerticalAxis.Custom;
            this.line.CustomVertAxis = this.axis3;
            this.line.DataSource     = this.candle;
            this.line.Function       = this.obvFunction;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Panel.MarginLeft  = 5;
            this.tChart.Axes.Left.Visible = false;

            this.tChart.Axes.Custom.Add(this.axis1);
            this.tChart.Axes.Custom.Add(this.axis2);
            this.tChart.Axes.Custom.Add(this.axis3);

            this.tChart.Series.Add(this.candle);
            this.tChart.Series.Add(this.volume);
            this.tChart.Series.Add(this.line);

            #endregion

            candle.FillSampleValues();
            volume.FillSampleValues();
            obvFunction.Recalculate();
        }

        #endregion
    }
}